@@ -2,44 +2,40 @@
 #define UICONTROLLER_H
 
 #include "routedata.h"
-#include "location.h"
+#include "logic/location.h"
 
 #include <QObject>
 
-class Ui;
+class UiClass;
 
 class UiController : public QObject
 {
   Q_OBJECT
 
 public:
-  UiController( Ui *ui );
+  UiController( UiClass *ui );
   ~UiController();
 
 public Q_SLOTS:
   void displayRoute( const QList<RouteData> &routeData );
+  //void updateLocationSelectors();
+  void changeFrom();
+  void changeTo();
+  void gpsBecameValid();
 
 Q_SIGNALS:
-  void buttonClicked();
-  void destinationChanged( Location *newDestination );
+  void routeSearchRequested();
+  void fromChanged(Location *newFromLocation);
+  void toChanged(Location *newToLocation);
 
 private Q_SLOTS:
-  void changeDestination( int id );
   void changeRoute( int id );
-  void setHomeButtonValid();
-  void setWorkButtonValid();
-  void setHomeButtonInValid();
-  void setWorkButtonInValid();
   void displayRouteDetail( int id );
-
-private:
-  void setButtonValid( int id, bool isValid );
+  void findRoute();
 
 private:
   QList<RouteData> m_routeData;
-  QList<Location*> m_destination;
-  Ui *m_ui;
-  int m_currentDestination;
+  UiClass *m_ui;
   int m_currentRoute;
 };
 #endif // UICONTROLLER_H
